"""
Provides the gfts routes file with route information. last update: 2020-02-22
"""

CSV_FILE = """\
route_id,route_short_name,route_long_name,route_desc,route_type,route_url,route_color,route_text_color
2,1,"GARE DE L'OUEST - STOCKEL",,1,,C4008F,FFFFFF
3,2,"SIMONIS - ELISABETH",,1,,F57000,FFFFFF
5,3,"ESPLANADE - CHURCHILL",,0,,B5BA05,000000
8,4,"GARE DU NORD - STALLE (P)",,0,,F25482,000000
1,5,"ERASME - HERRMANN-DEBROUX",,1,,E6B012,FFFFFF
4,6,"ROI BAUDOUIN - ELISABETH",,1,,0078AD,FFFFFF
6,7,"VANDERKINDERE - HEYSEL",,0,,FFF06E,000000
9,8,"LOUISE - ROODEBEEK",,0,,00A1DF,000000
10,9,"SIMONIS - ARBRE BALLON",,0,,DB3EB1,000000
66,12,"BRUSSELS AIRPORT - BRUSSELS CITY",,3,,338C26,FFFFFF
23,13,"ETANGS NOIRS - UZ-VUB",,3,,9EBFE3,000000
24,14,"HEYSEL - GARE DU NORD",,3,,FF9EC2,000000
47,17,"BEAULIEU - HEILIGENBORRE",,3,,DE3B21,FFFFFF
12,19,"GROOT-BIJGAARDEN - DE WAND",,0,,DE3B21,FFFFFF
25,20,"HUNDERENVELD - GARE DU NORD",,3,,E3BA12,000000
72,21,"MAES - LUXEMBOURG",,3,,F7E017,000000
14,25,"BOONDAEL GARE - ROGIER",,0,,991F36,FFFFFF
48,27,"GARE DU MIDI - ANDROMEDE",,3,,9EBFE3,000000
65,27,"GARE DU MIDI - PLEIADES",,3,,9EBFE3,000000
49,28,"BRABANCONNE - KONKEL",,3,,DE3B21,FFFFFF
67,29,"DE BROUCKERE - HOF TEN BERG",,3,,E87D0D,FFFFFF
22,32,"DA VINCI - DROGENBOS CHATEAU",,0,,F7E017,000000
27,33,"DANSAERT - LOUISE",,3,,FF9EC2,000000
50,34,"PORTE DE NAMUR - SAINTE-ANNE",,3,,E3BA12,000000
51,36,"SCHUMAN - KONKEL",,3,,9EBFE3,000000
28,37,"ALBERT - GARE DE LINKEBEEK",,3,,36578C,FFFFFF
52,38,"GARE CENTRALE - HEROS",,3,,B085B3,FFFFFF
17,39,"MONTGOMERY - BAN-EIK",,0,,DE3B21,FFFFFF
53,41,"HEROS - TRANSVAAL",,3,,9EBFE3,000000
69,42,"VIADUC E40 - ROODEBEEK",,3,,338C26,FFFFFF
29,43,"OBSERVATOIRE - VIVIER D'OIE",,3,,996308,FFFFFF
16,44,"MONTGOMERY - TERVUREN STATION",,0,,E3BA12,000000
70,45,"ROODEBEEK - SAINT-VINCENT",,3,,B085B3,FFFFFF
30,46,"MOORTEBEEK - GLIBERT",,3,,DE3B21,FFFFFF
87,47,"DE BROUCKERE - VILVOORDE STATION",,3,,B085B3,FFFFFF
90,47,"HEEMBEEK - VILVOORDE STATION",,3,,B085B3,FFFFFF
83,48,"ANNEESSENS - DECROLY",,3,,338C26,FFFFFF
33,49,"GARE DU MIDI - SIMONIS",,3,,36578C,FFFFFF
34,50,"GARE DU MIDI - LOT STATION",,3,,B5BA05,000000
13,51,"STADE - VAN HAELEN",,0,,E3BA12,000000
88,53,"WESTLAND SHOPPING - HOPITAL MILITAIRE",,3,,338C26,FFFFFF
35,54,"TRONE - FOREST (BERVOETS)",,3,,DE3B21,FFFFFF
15,55,"DA VINCI - ROGIER",,0,,E3BA12,000000
91,56,"SCHUMAN - BUDA",,3,,E87D0D,FFFFFF
89,57,"GARE DU NORD - HOPITAL MILITAIRE",,3,,DE3B21,FFFFFF
74,58,"VILVOORDE STATION - YSER",,3,,338C26,FFFFFF
75,59,"HOPITAL ETTERBEEK-IXELLES - BORDET STATION",,3,,996308,FFFFFF
54,60,"AMBIORIX - UCCLE CALEVOET",,3,,FF9EC2,000000
55,61,"GARE DU NORD - MONTGOMERY",,3,,F7E017,000000
7,62,"EUROCONTROL - CIMETIERE DE JETTE",,0,,FF9EC2,000000
76,63,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,9EBFE3,000000
78,64,"PORTE DE NAMUR - BORDET STATION",,3,,DE3B21,FFFFFF
77,65,"GARE CENTRALE - MACHELEN",,3,,E3BA12,000000
68,66,"DE BROUCKERE - PEAGE",,3,,36578C,FFFFFF
73,69,"SCHAERBEEK GARE - JULES BORDET",,3,,E87D0D,FFFFFF
56,71,"DE BROUCKERE - DELTA",,3,,338C26,FFFFFF
57,72,"ULB - ADEPS",,3,,FF9EC2,000000
36,75,"CAMPUS CERIA - BON AIR",,3,,F7E017,000000
45,75,"CERIA - BON AIR",,3,,F7E017,000000
58,76,"KRAAINEM - OPPEM",,3,,F7E017,000000
59,77,"KRAAINEM - HIPPODROME",,3,,338C26,FFFFFF
84,78,"HUMANITE - GARE DU MIDI",,3,,B085B3,FFFFFF
71,79,"KRAAINEM - SCHUMAN",,3,,36578C,FFFFFF
60,80,"PORTE DE NAMUR - HAREN",,3,,338C26,FFFFFF
18,81,"MARIUS RENARD - MONTGOMERY",,0,,338C26,FFFFFF
11,82,"BERCHEM STATION - DROGENBOS CHATEAU",,0,,9EBFE3,000000
38,83,"BERCHEM STATION - HEYSEL",,3,,B5BA05,000000
32,86,"MACHTENS - GARE CENTRALE",,3,,338C26,FFFFFF
26,87,"SIMONIS - BEEKKANT",,3,,338C26,FFFFFF
39,88,"DE BROUCKERE - UZ-VUB",,3,,991F36,FFFFFF
31,89,"WESTLAND SHOPPING - BOCKSTAEL",,3,,E87D0D,FFFFFF
20,92,"SCHAERBEEK GARE - FORT-JACO",,0,,DE3B21,FFFFFF
21,93,"STADE - LEGRAND",,0,,E87D0D,FFFFFF
61,95,"GRAND-PLACE - WIENER",,3,,36578C,FFFFFF
19,97,"LOUISE - DIEWEG",,0,,991F36,FFFFFF
37,98,"CERIA - HEROS",,3,,FC8306,FFFFFF
46,T39,"MARCELIS - BAN-EIK",,3,,DE3B21,FFFFFF
64,T39,"STOCKEL - BAN-EIK",,3,,DE3B21,FFFFFF
82,T55,"DA VINCI - ROGIER",,3,,E3BA12,000000
40,T93,"STADE - LEGRAND",,3,,E87D0D,FFFFFF
80,N04,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,FF00FF,FFFFFF
81,N05,"GARE CENTRALE - KRAAINEM",,3,,9978B8,FFFFFF
79,N06,"GARE CENTRALE - MUSEE DU TRAM",,3,,00C8FF,FFFFFF
62,N08,"GARE CENTRALE - WIENER",,3,,94C9FD,000000
63,N09,"GARE CENTRALE - HERRMANN-DEBROUX",,3,,FF00FF,FFFFFF
41,N10,"GARE CENTRALE - FORT-JACO",,3,,D2FF0A,000000
85,N11,"GARE CENTRALE - HOMBORCH",,3,,976A0E,FFFFFF
43,N12,"GARE CENTRALE - CARREFOUR STALLE",,3,,FC8306,FFFFFF
86,N13,"GARE CENTRALE - WESTLAND SHOPPING",,3,,C30C3E,FFFFFF
44,N16,"GARE CENTRALE - BERCHEM STATION",,3,,0A3C0A,FFFFFF
42,N18,"GARE CENTRALE - HEYSEL",,3,,64D214,FFFFFF
"""
